=======
History
=======

0.3.0 (2016-09-03)
-------------------

* Optimize scanning by using a new tiny list of frequently used subdomains
* Introduce more efficient and faster default scanning mode, agressive scanning mode, and user keywords list based on scanning mode

0.2.0 (2016-09-03)
-------------------

* New docker tag for allow anonymous scanning. Integrate a second dockerfile for build a container where network connections are relayed per a tor client embdded inside this container.

0.1.16 (2016-09-02)
-------------------

* Apply Alpha development status for pypi classifiers
* Adding badges on README

0.1.15 (2016-09-01)
-------------------

* Fixing mistake on Dockerfile (docker run command)

0.1.14 (2016-09-01)
-------------------

* Fixing bad packaging. Error when loading dictionaries files.

0.1.13 (2016-09-01)
-------------------

* Link official webpage with repo (pypi, github, docker)

0.1.12 (2016-08-31)
-------------------

* Fix somes documentation mistakes and syntax error
* Update pypi project classifiers

0.1.11 (2016-08-31)
-------------------

* Fix somes documentation mistakes and syntax error

0.1.10 (2016-08-31)
-------------------

* Dockerize app
* Stable pypi deployment via travis-ci

0.1.6 (2016-08-31)
------------------

* First release on Pypi.
* Using click instead of argparse

0.1.0 (2016-08-29)
------------------

* First release on Github.
